# SapphireUI

Pre-designed UI components built with Reflex. Easily copy and paste into your own app.

<p align="center">
  <img src="https://res.cloudinary.com/douedu8ss/image/upload/v1762596019/sapphireui-blue-book.reflex.run_Laptop_2025-11-08_09.58.37_zz3btb.png" alt="Logo" width="100%" style="border-radius: 10px; box-shadow: 0 8px 16px rgba(0, 0, 0, 0.1); border: 2px solid #333;">
</p>
<p align="center">
  <img src="https://res.cloudinary.com/douedu8ss/image/upload/v1762596019/sapphireui-blue-book.reflex.run_Laptop_2025-11-08_09.59.16_m31odc.png" alt="Logo" width="100%" style="border-radius: 10px; box-shadow: 0 8px 16px rgba(0, 0, 0, 0.1); border: 2px solid #333;">
</p>


## Pantry

Visit the [Pantry](https://sapphireui-blue-book.reflex.run/pantry/accordions/) section to view the available pre-built components.

## Charts

Visit the [Charts](https://sapphireui-blue-book.reflex.run/charts/area-charts/) section to view the available pre-built charts for data visualization.

## Contributing

Please read this [guide](CONTRIBUTING.md) for more information on how to contribute.

## License

Licensed under the [MIT license](./LICENSE).
